@@ -37,17 +37,27 @@ class Target(object):
             sys.exit(1)
 
     def query(self):
-        catalogData = Catalogs.query_object('TIC' + str(self.tic), catalog="TIC")
+        catalogData = Catalogs.query_object('TIC' + str(self.tic), catalog="TIC", radius=3 * u.arcsec)
         return catalogData
 
 
 def print_results(tic=12350, simbad_search=False):
     target = Target(tic)
-    catalogData = target.query()
+    catalogData = target.query()[0]
+
+    catalogData['ra'] = catalogData['ra'].round(6)
+    catalogData['dec'] = catalogData['dec'].round(6)
+    catalogData['eclong'] = catalogData['eclong'].round(6)
+    catalogData['eclat'] = catalogData['eclat'].round(6)
+    catalogData['pmRA'] = catalogData['pmRA'].round(2)
+    catalogData['pmDEC'] = catalogData['pmDEC'].round(2)
+    catalogData['Tmag'] = catalogData['Tmag'].round(2)
+    catalogData['Vmag'] = catalogData['Vmag'].round(2)
+    catalogData['Kmag'] = catalogData['Kmag'].round(2)
 
     print(catalogData[['ID', 'ra', 'dec', 'pmRA', 'pmDEC',
                        'eclong', 'eclat', 'Tmag', 'Vmag', 'Kmag', 'Teff',
-                       'rad', 'mass', 'd', ]][0])
+                       'rad', 'mass', 'd', ]])
 
     if simbad_search:
         skobj = SkyCoord(ra=catalogData['ra'] * u.degree,
@@ -58,7 +68,7 @@ def print_results(tic=12350, simbad_search=False):
 
             customSimbad = Simbad()
             customSimbad.add_votable_fields(
-                'ra(2;A;ICRS;J2000;2000)', 'dec(2;D;ICRS;2000;2000)')
+                'ra(2;A;ICRS;J2000;2000)', 'dec(2;D;ICRS;J2000;2000)')
             customSimbad.remove_votable_fields('coordinates')
 
             # try different search radii, be fast if possible
@@ -77,7 +87,7 @@ def print_results(tic=12350, simbad_search=False):
             print('Target name: {}'.format(
                 result_table['MAIN_ID'][0].decode('utf-8')))
         print("The target is in constellation {}".format(get_constellation(
-            skobj)[0]))
+            skobj)))
 
     print()
 
@@ -155,7 +165,7 @@ def get_tic_radec(ra, dec):
         warnings.simplefilter('ignore')
         catalogData = Catalogs.query_region('{} {}'.format(
             ra, dec),
-            catalog='Tic', radius=0.006)
+            catalog='Tic', radius=1 * u.arcsec)
 
     try:
         return catalogData['ID'][0]
@@ -167,7 +177,7 @@ def get_tic_name(name):
     with warnings.catch_warnings():
         warnings.simplefilter('ignore')
         customSimbad = Simbad()
-        customSimbad.add_votable_fields('ra(2;A;ICRS;J2000;2000)', 'dec(2;D;ICRS;2000;2000)')
+        customSimbad.add_votable_fields('ra(2;A;ICRS;J2000;2000)', 'dec(2;D;ICRS;J2000;2000)')
         customSimbad.remove_votable_fields('coordinates')
         result_table = customSimbad.query_object(name)
     if result_table is None:
@@ -177,7 +187,7 @@ def get_tic_name(name):
     with warnings.catch_warnings():
         warnings.simplefilter('ignore')
         ra_sex = result_table['RA_2_A_ICRS_J2000_2000'][0]
-        dec_sex = result_table['DEC_2_D_ICRS_2000_2000'][0]
+        dec_sex = result_table['DEC_2_D_ICRS_J2000_2000'][0]
         catalogData = Catalogs.query_region(SkyCoord
             (ra_sex, dec_sex, unit=(u.hour, u.deg)),
             catalog='Tic', radius=0.006)
